NetworkConfiguration class Initialization and configuration

Configuration of the collector network endpoint.

Annotations

Constructors

NetworkConfiguration({required String endpoint, Method? method, String? customPostPath, Map<String, String>? requestHeaders})
const

Properties

customPostPath → String?
Set a path for POST requests. This will override the default "com.snowplowanalytics.snowplow/tp2" path. You will need to configure your collector to accept your custom path.
final
endpoint → String
Endpoint of the collector, e.g. http://localhost:9090
final
hashCode → int
The hash code for this object.
no setterinherited
method → Method?
Choice of GET or POST (default) HTTP method used to send events to the collector.
final
requestHeaders → Map<String, String>?
Custom HTTP headers to add to HTTP requests to the collector.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited