TrackerConfiguration class Initialization and configuration Sessions and data model

Configuration of the tracker and the core tracker properties.

Indicates what should be tracked in terms of automatic tracking and contexts/entities to attach to the events.

Annotations

Constructors

TrackerConfiguration({String? appId, DevicePlatform? devicePlatform, bool? base64Encoding, bool? platformContext, bool? geoLocationContext, bool? sessionContext, bool? webPageContext, bool? screenContext, bool? applicationContext, WebActivityTracking? webActivityTracking, bool? userAnonymisation, bool? lifecycleAutotracking, bool? screenEngagementAutotracking, PlatformContextProperties? platformContextProperties, String? jsMediaPluginURL})
const

Properties

appId → String?
Identifier of the app.
final
applicationContext → bool?
Indicates whether application context should be attached to tracked events.
final
base64Encoding → bool?
Indicates whether payload JSON data should be base64 encoded.
final
devicePlatform → DevicePlatform?
The device platform the tracker runs on.
final
geoLocationContext → bool?
Indicates whether geo-location context should be attached to tracked events.
final
hashCode → int
The hash code for this object.
no setterinherited
jsMediaPluginURL → String?
The URL of the media plugin for the JavaScript tracker. Required in order to track media events on Web. You may use it from CDN as: https://cdn.jsdelivr.net/npm/@snowplow/browser-plugin-media@latest/dist/index.umd.min.js
final
lifecycleAutotracking → bool?
Indicates whether to enable automatic tracking of background and foreground transitions.
final
platformContext → bool?
Indicates whether platform context should be attached to tracked events.
final
platformContextProperties → PlatformContextProperties?
Overrides for the values for properties of the platform context. Only available on mobile apps (Android and iOS), not on Web.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenContext → bool?
Indicates whether screen context should be attached to tracked events.
final
screenEngagementAutotracking → bool?
Whether to enable tracking of the screen end event and the screen summary context entity.
final
sessionContext → bool?
Indicates whether session context should be attached to tracked events.
final
userAnonymisation → bool?
Indicates whether user identifiers should be anonymised.
final
webActivityTracking → WebActivityTracking?
Configuration for activity tracking on the Web and use of PageViewEvent events in auto tracking from SnowplowObserver observers.
final
webPageContext → bool?
Indicates whether context about current web page should be attached to tracked events.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited