DeepLinkReceived class Tracking events

Event to track a received deep link.

Not supported on Web.

Implemented types
Annotations

Constructors

DeepLinkReceived({required String url, String? referrer})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
referrer String?
The referrer URL of the deep link.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
The URL of the deep link.
final

Methods

endpoint() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited