bodyLocArgs property
Variable string values to appear in place of the format specifiers in bodyLocKey.
Implementation
final List<String>? bodyLocArgs;
Variable string values to appear in place of the format specifiers in bodyLocKey.
final List<String>? bodyLocArgs;