MessageNotificationAttachment class
An attachment to a MessageNotification event.
- Annotations
Constructors
- MessageNotificationAttachment({required String identifier, required String type, required String url})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
A unique identifier for the attachment.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The content type of the attachment.
final
- url → String
-
The URL of the attachment content.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited