ScrollChanged class Adding data to your events Tracking events

Event tracked when a scroll view's scroll position changes. If screen engagement tracking is enabled, the scroll changed events will be aggregated into a screen_summary entity.

Schema: iglu:com.snowplowanalytics.mobile/scroll_changed/jsonschema/1-0-0

Implemented types
Annotations

Constructors

ScrollChanged({int? yOffset, int? xOffset, int? viewHeight, int? viewWidth, int? contentHeight, int? contentWidth})
const

Properties

contentHeight → int?
The height of the content in the scroll view in pixels
final
contentWidth → int?
The width of the content in the scroll view in pixels
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewHeight → int?
The height of the scroll view in pixels
final
viewWidth → int?
The width of the scroll view in pixels
final
xOffset → int?
Horizontal scroll offset in pixels.
final
yOffset → int?
Vertical scroll offset in pixels
final

Methods

endpoint() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited